Class: Google::Apis::MarketingplatformadminV1alpha::PropertyUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/marketingplatformadmin_v1alpha/classes.rb,
lib/google/apis/marketingplatformadmin_v1alpha/representations.rb,
lib/google/apis/marketingplatformadmin_v1alpha/representations.rb

Overview

Contains the count of events received by the property, along with metadata that influences the volume of billable events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PropertyUsage

Returns a new instance of PropertyUsage.



404
405
406
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

The ID of the property's parent account. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


371
372
373
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 371

def 
  @account_id
end

#billable_event_countFixnum

The number of events for which the property is billed in the requested month. Corresponds to the JSON property billableEventCount

Returns:

  • (Fixnum)


376
377
378
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 376

def billable_event_count
  @billable_event_count
end

#display_nameString

The display name of the property. Corresponds to the JSON property displayName

Returns:

  • (String)


381
382
383
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 381

def display_name
  @display_name
end

#propertyString

The name of the Google Analytics Admin API property resource. Format: analyticsadmin.googleapis.com/properties/property_id Corresponds to the JSON property property

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 387

def property
  @property
end

#property_typeString

The subtype of the analytics property. This affects the billable event count. Corresponds to the JSON property propertyType

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 392

def property_type
  @property_type
end

#service_levelString

The service level of the property. Corresponds to the JSON property serviceLevel

Returns:

  • (String)


397
398
399
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 397

def service_level
  @service_level
end

#total_event_countFixnum

Total event count that the property received during the requested month. Corresponds to the JSON property totalEventCount

Returns:

  • (Fixnum)


402
403
404
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 402

def total_event_count
  @total_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



409
410
411
412
413
414
415
416
417
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 409

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @billable_event_count = args[:billable_event_count] if args.key?(:billable_event_count)
  @display_name = args[:display_name] if args.key?(:display_name)
  @property = args[:property] if args.key?(:property)
  @property_type = args[:property_type] if args.key?(:property_type)
  @service_level = args[:service_level] if args.key?(:service_level)
  @total_event_count = args[:total_event_count] if args.key?(:total_event_count)
end