Class: Google::Apis::MarketingplatformadminV1alpha::ReportPropertyUsageResponse
- Inherits:
-
Object
- Object
- Google::Apis::MarketingplatformadminV1alpha::ReportPropertyUsageResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/marketingplatformadmin_v1alpha/classes.rb,
lib/google/apis/marketingplatformadmin_v1alpha/representations.rb,
lib/google/apis/marketingplatformadmin_v1alpha/representations.rb
Overview
Response message for ReportPropertyUsage RPC.
Instance Attribute Summary collapse
-
#bill_info ⇒ Google::Apis::MarketingplatformadminV1alpha::BillInfo
Contains the bill amount.
-
#property_usages ⇒ Array<Google::Apis::MarketingplatformadminV1alpha::PropertyUsage>
Usage data for all properties in the specified organization and month.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportPropertyUsageResponse
constructor
A new instance of ReportPropertyUsageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportPropertyUsageResponse
Returns a new instance of ReportPropertyUsageResponse.
454 455 456 |
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bill_info ⇒ Google::Apis::MarketingplatformadminV1alpha::BillInfo
Contains the bill amount.
Corresponds to the JSON property billInfo
447 448 449 |
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 447 def bill_info @bill_info end |
#property_usages ⇒ Array<Google::Apis::MarketingplatformadminV1alpha::PropertyUsage>
Usage data for all properties in the specified organization and month.
Corresponds to the JSON property propertyUsages
452 453 454 |
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 452 def property_usages @property_usages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
459 460 461 462 |
# File 'lib/google/apis/marketingplatformadmin_v1alpha/classes.rb', line 459 def update!(**args) @bill_info = args[:bill_info] if args.key?(:bill_info) @property_usages = args[:property_usages] if args.key?(:property_usages) end |